@@ -359,6 +359,7 @@ extern double                opy;
 extern int                   orbitsave;
 extern int                   orbit_color;
 extern int                   orbit_delay;
+extern long                  orbit_interval;
 extern int                   orbit_ptr;
 extern char                  orgfrmdir[];
 extern int                   orgfrmsearch;
@@ -653,6 +654,7 @@ extern char                  s_off[];
 extern char                  s_olddemmcolors[];
 extern char                  s_one[];
 extern char                  s_orbitdelay[];
+extern char                  s_orbitinterval[];
 extern char                  s_orbitname[];
 extern char                  s_orbitsave[];
 extern char                  s_orgfrmdir[];
