@@ -3,12 +3,15 @@ FRACSUBR.C contains subroutines which belong primarily to CALCFRAC.C and
 FRACTALS.C, i.e. which are non-fractal-specific fractal engine subroutines.
 */
 
-#ifndef XFRACT
+#ifndef USE_VARARGS
 #include <stdarg.h>
-#include <sys/timeb.h>
 #else
 #include <varargs.h>
 #endif
+
+#ifndef XFRACT
+#include <sys/timeb.h>
+#endif
 #include <sys/types.h>
 #include <time.h>
   /* see Fractint.c for a description of the "include"  hierarchy */
@@ -122,7 +125,10 @@ void calcfracinit(void) /* initialize a *pile* of stuff for fractal calculation
  
   /* set up grid array compactly leaving space at end */
    if(xdots > OLDMAXPIXELS || ydots > OLDMAXPIXELS || debugflag==3800)
+   {
       use_grid=0;
+      floatflag = usr_floatflag = 1;
+   }
    else
       use_grid=1;   
    set_grid_pointers();
@@ -187,11 +193,12 @@ void calcfracinit(void) /* initialize a *pile* of stuff for fractal calculation
       floatflag=1;
    else
       floatflag = usr_floatflag;
-   if (calc_status == 2) /* on resume, ensure floatflag correct */
+   if (calc_status == 2) { /* on resume, ensure floatflag correct */
       if (curfractalspecific->isinteger)
          floatflag = 0;
       else
          floatflag = 1;
+   }
    /* if floating pt only, set floatflag for TAB screen */
    if (!curfractalspecific->isinteger && curfractalspecific->tofloat == NOFRACTAL)
       floatflag = 1;
@@ -219,7 +226,7 @@ init_restart:
          || curfractalspecific->calctype == calcmand
          || curfractalspecific->calctype == calcmandfp)) {
       potflag = 1;
-      distest = 0;    /* can't do distest too */
+      distest = usr_distest = 0;    /* can't do distest too */
       }
 
    if (distest)
@@ -283,7 +290,7 @@ init_restart:
    bitshift = FUDGEFACTOR2; /* by default, the smaller shift */
    if (integerfractal > 1)  /* use specific override from table */
       bitshift = integerfractal;
-   if (integerfractal == 0) /* float? */
+   if (integerfractal == 0) { /* float? */
       if ((i = curfractalspecific->tofloat) != NOFRACTAL) /* -> int? */
       {
          if (fractalspecific[i].isinteger > 1) /* specific shift? */
@@ -291,6 +298,7 @@ init_restart:
       }
       else
          bitshift = 16;  /* to allow larger corners */
+   }
 /* We want this code if we're using the assembler calcmand */
    if (fractype == MANDEL || fractype == JULIA) { /* adust shift bits if.. */
       if (potflag == 0                            /* not using potential */
@@ -342,9 +350,12 @@ init_restart:
 
    /* skip this if plasma to avoid 3d problems */
    /* skip if bf_math to avoid extraseg conflict with dx0 arrays */
-   if (fractype != PLASMA && bf_math == 0)
+   /* skip if ifs, ifs3d, or lsystem to avoid crash when mathtolerance */
+   /* is set.  These types don't auto switch between float and integer math */
+   if (fractype != PLASMA && bf_math == 0
+       && fractype != IFS && fractype != IFS3D && fractype != LSYSTEM)
    {
-      if (integerfractal && !invert)
+      if (integerfractal && !invert && use_grid)
       {
          if (   (delx  == 0 && delxx  != 0.0)
              || (delx2 == 0 && delxx2 != 0.0)
@@ -381,7 +392,7 @@ expand_retry:
          yymin = fudgetodouble(ymin);
          yymax = fudgetodouble(ymax);
          yy3rd = fudgetodouble(y3rd);
-      } /* end if (integerfractal && !invert) */
+      } /* end if (integerfractal && !invert && use_grid) */
       else
       {
          double dx0,dy0,dx1,dy1;
@@ -1028,11 +1039,11 @@ static int _fastcall ratio_bad(double actual, double desired)
 
    Example, save info:
       alloc_resume(sizeof(parmarray)+100,2);
-      put_resume(sizeof(int),&row, sizeof(int),&col,
+      put_resume(sizeof(row),&row, sizeof(col),&col,
                  sizeof(parmarray),parmarray, 0);
     restore info:
       vsn = start_resume();
-      get_resume(sizeof(int),&row, sizeof(int),&col, 0);
+      get_resume(sizeof(row),&row, sizeof(col),&col, 0);
       if (vsn >= 2)
          get_resume(sizeof(parmarray),parmarray,0);
       end_resume();
@@ -1050,7 +1061,7 @@ static int _fastcall ratio_bad(double actual, double desired)
 
    */
 
-#ifndef XFRACT
+#ifndef USE_VARARGS
 int put_resume(int len, ...)
 #else
 int put_resume(va_alist)
@@ -1059,13 +1070,13 @@ va_dcl
 {
    va_list arg_marker;  /* variable arg list */
    BYTE *source_ptr;
-#ifdef XFRACT
+#ifdef USE_VARARGS
    int len;
 #endif
 
    if (resume_info == 0)
       return(-1);
-#ifndef XFRACT
+#ifndef USE_VARARGS
    va_start(arg_marker,len);
 #else
    va_start(arg_marker);
@@ -1079,6 +1090,7 @@ va_dcl
       resume_len += len;
       len = va_arg(arg_marker,int);
    }
+   va_end(arg_marker);
    return(0);
 }
 
@@ -1086,7 +1098,7 @@ int alloc_resume(int alloclen, int version)
 { /* WARNING! if alloclen > 4096B, problems may occur with GIF save/restore */
    if (resume_info != 0) /* free the prior area if there is one */
       MemoryRelease(resume_info);
-   if ((resume_info = MemoryAlloc((U16)sizeof(int), (long)alloclen, FARMEM)) == 0)
+   if ((resume_info = MemoryAlloc((U16)sizeof(alloclen), (long)alloclen, FARMEM)) == 0)
    {
       static FCODE msg[] = {"\
 Warning - insufficient free memory to save status.\n\
@@ -1096,12 +1108,12 @@ You will not be able to resume calculating this image."};
       return(-1);
    }
    resume_len = 0;
-   put_resume(sizeof(int),&version,0);
+   put_resume(sizeof(version),&version,0);
    calc_status = 2;
    return(0);
 }
 
-#ifndef XFRACT
+#ifndef USE_VARARGS
 int get_resume(int len, ...)
 #else
 int get_resume(va_alist)
@@ -1110,13 +1122,13 @@ va_dcl
 {
    va_list arg_marker;  /* variable arg list */
    BYTE *dest_ptr;
-#ifdef XFRACT
+#ifdef USE_VARARGS
    int len;
 #endif
 
    if (resume_info == 0)
       return(-1);
-#ifndef XFRACT
+#ifndef USE_VARARGS
    va_start(arg_marker,len);
 #else
    va_start(arg_marker);
@@ -1130,6 +1142,7 @@ va_dcl
       resume_offset += len;
       len = va_arg(arg_marker,int);
    }
+   va_end(arg_marker);
    return(0);
 }
 
@@ -1139,7 +1152,7 @@ int start_resume(void)
    if (resume_info == 0)
       return(-1);
    resume_offset = 0;
-   get_resume(sizeof(int),&version,0);
+   get_resume(sizeof(version),&version,0);
    return(version);
 }
 
@@ -1458,9 +1471,11 @@ static int _fastcall combine_worklist(void) /* look for 2 entries which can free
          for (j=i+1; j<num_worklist; ++j)
             if (worklist[j].sym == worklist[i].sym
                 && worklist[j].yystart == worklist[j].yybegin
+                && worklist[j].xxstart == worklist[j].xxbegin
                 && worklist[i].pass == worklist[j].pass)
             {
                if ( worklist[i].xxstart == worklist[j].xxstart
+                   && worklist[i].xxbegin == worklist[j].xxbegin
                    && worklist[i].xxstop  == worklist[j].xxstop)
                {
                   if (worklist[i].yystop+1 == worklist[j].yystart)
@@ -1476,6 +1491,7 @@ static int _fastcall combine_worklist(void) /* look for 2 entries which can free
                   }
                }
                if ( worklist[i].yystart == worklist[j].yystart
+                   && worklist[i].yybegin == worklist[j].yybegin
                    && worklist[i].yystop  == worklist[j].yystop)
                {
                   if (worklist[i].xxstop+1 == worklist[j].xxstart)
@@ -1486,6 +1502,7 @@ static int _fastcall combine_worklist(void) /* look for 2 entries which can free
                   if (worklist[j].xxstop+1 == worklist[i].xxstart)
                   {
                      worklist[i].xxstart = worklist[j].xxstart;
+                     worklist[i].xxbegin = worklist[j].xxbegin;
                      return(j);
                   }
                }
