@@ -6,12 +6,17 @@
 #include <string.h>
 #include <time.h>
 #include <signal.h>
+
 #ifndef XFRACT
 #include <io.h>
+#endif
+
+#ifndef USE_VARARGS
 #include <stdarg.h>
 #else
 #include <varargs.h>
 #endif
+
 #include <ctype.h>
 
   /* #include hierarchy for fractint is a follows:
@@ -129,6 +134,8 @@ int compiled_by_turboc = 0;
         int     viewcrop;               /* nonzero to crop default coords */
         float   finalaspectratio;       /* for view shape and rotation */
         int     viewxdots,viewydots;    /* explicit view sizing */
+        int     video_cutboth;          /* nonzero to keep virtual aspect */
+        int     zscroll;                /* screen/zoombox 0 fixed, 1 relaxed */
 
 /*      HISTORY  far *history = NULL; */
         U16 history = 0;
@@ -202,7 +209,12 @@ static void my_floating_point_err(int sig)
       overflow = 1;
 }
 
-void main(int argc, char **argv)
+#ifdef XFRACT
+int
+#else
+void
+#endif
+main(int argc, char **argv)
 {
    int     resumeflag;
    int     kbdchar;                     /* keyboard key-hit value       */
@@ -240,11 +252,13 @@ restart:   /* insert key re-starts here */
    opy = newopy = -1.5;
    odpx = odpy = 0;
    gridsz = 9;
-   fiddlefactor = 1; fiddle_reduction = 1.0;
+   fiddlefactor = 1;
+   fiddle_reduction = 1.0;
    this_gen_rseed = (unsigned int)clock_ticks();
    srand(this_gen_rseed);
    initgene(); /*initialise pointers to lots of fractint variables for the evolution engine*/
    start_showorbit = 0;
+   showdot = -1; /* turn off showdot if entered with <g> command */
 
    if (fract_dir1==NULL)
        fract_dir1 = ".";
@@ -424,7 +438,11 @@ imagestart:                             /* calc/display a new image */
 #endif
       if (kbdchar == 'd') {                     /* shell to DOS */
          setclear();
+#ifndef XFRACT
          printf("\n\nShelling to DOS - type 'exit' to return\n\n");
+#else
+         printf("\n\nShelling to Linux/Unix - type 'exit' to return\n\n");
+#endif
          shell_to_dos();
          goto imagestart;
          }
@@ -516,6 +534,9 @@ resumeloop:
    default:
       break;
    }
+#ifdef XFRACT
+   return(0);
+#endif
 }
 
 int check_key()
@@ -540,7 +561,7 @@ int check_key()
      timer(1,NULL,int width)            decoder
      timer(2)                           encoder
   */
-#ifndef XFRACT
+#ifndef USE_VARARGS
 int timer(int timertype,int(*subrtn)(),...)
 #else
 int timer(va_alist)
@@ -555,7 +576,7 @@ va_dcl
    int i;
    int do_bench;
 
-#ifndef XFRACT
+#ifndef USE_VARARGS
    va_start(arg_marker,subrtn);
 #else
    int timertype;
