@@ -311,6 +311,11 @@ int read_overlay()      /* read overlay/3D files, if reqr'd */
    /* modified saved evolver structure JCO 12JUL01 */
    Log_Auto_Calc = 0;  /* make sure it's turned off */
 
+   orbit_interval = 1;
+   if (read_info.version > 15) { /* post-version 20.3.2 */
+      orbit_interval = read_info.orbit_interval;
+   }
+
    backwards_v18();
    backwards_v19();
    backwards_v20();
@@ -1036,7 +1041,10 @@ int ret = 0;
        (fractype == LPOPCORNJUL && save_release <= 1960) ||
        (inside == FMODI && save_release <= 2000) ||
        ((inside == ATANI || outside == ATAN) && save_release <= 2002) ||
-       (fractype == LAMBDATRIGFP && trigndx[0] == EXP && save_release <= 2002)
+       (fractype == LAMBDATRIGFP && trigndx[0] == EXP && save_release <= 2002) ||
+       ((fractype == JULIBROT || fractype == JULIBROTFP) &&
+          (neworbittype == QUATFP || neworbittype == HYPERCMPLXFP) &&
+           save_release <= 2002)
        )
      ret = 1;
    return(ret);
