@@ -1,12 +1,17 @@
 #include <string.h>
 #include <limits.h>
 #include <malloc.h>
+
 #ifndef XFRACT
 #include <io.h>
+#endif
+
+#ifndef USE_VARARGS
 #include <stdarg.h>
 #else
 #include <varargs.h>
 #endif
+
 #include <ctype.h>
 
 #include "port.h"
@@ -110,6 +115,7 @@ static int check_for_mem(int stored_at, long howmuch);
 static U16 next_handle(void);
 static int CheckBounds (long start, long length, U16 handle);
 static void WhichDiskError(int);
+static void DisplayError(int stored_at, long howmuch);
 
 /* Routines in this module, visible to outside routines */
 
@@ -221,15 +227,33 @@ int MemoryType (U16 handle)
    return (handletable[handle].Nowhere.stored_at);
 }
 
+static void DisplayError(int stored_at, long howmuch)
+{
+/* This routine is used to display an error message when the requested */
+/* memory type cannot be allocated due to insufficient memory, AND there */
+/* is also insufficient disk space to use as memory. */
+
+   char buf[MSGLEN*2];
+   char nmsg[MSGLEN*2];
+   static FCODE fmsg[] = {"Allocating %ld Bytes of %s memory failed.\nAlternate disk space is also insufficient. Goodbye"};
+   far_strcpy(nmsg,fmsg);
+   sprintf(buf,nmsg,howmuch,memstr[stored_at]);
+   stopmsg(0,(char far *)buf);
+}
+
 static int check_for_mem(int stored_at, long howmuch)
 {
 /* This function returns an adjusted stored_at value. */
 /* This is where the memory requested can be allocated. */
 
+#ifndef XFRACT
    long usedmem, totalmem;
-   long maxmem,longtmp;
+   long longtmp;
+   int counter;
+#endif
+   long maxmem;
    BYTE far *temp;
-   int counter, use_this_type;
+   int use_this_type;
 
    use_this_type = NOWHERE;
    maxmem = (long)USHRT_MAX; /* limit EXTRA and FARMEM to 64K */
@@ -360,17 +384,13 @@ static int CheckBounds (long start, long length, U16 handle)
 
 void DisplayMemory (void)
 {
+#ifndef XFRACT
    long tmpfar;
    U32 tmpdisk;
    char buf[MSGLEN];
    char nmsg[MSGLEN];
-#ifdef XFRACT
-   static FCODE fmsg[] = {"far=%ld, disk=%lu"};
-#else
+/* #ifdef XFRACT   static FCODE fmsg[] = {"far=%ld, disk=%lu"}; */
    static FCODE fmsg[] = {"extra=%ld, far=%ld, expanded=%ld,\nextended=%ld, disk=%lu"};
-#endif
-
-#ifndef XFRACT
    long tmpextra, tmpexp, tmpext;
 
    tmpextra = USHRT_MAX - start_avail_extra;
@@ -407,7 +427,9 @@ void DisplayHandle (U16 handle)
 void InitMemory (void)
 {
    int counter;
+#ifndef XFRACT
    long longtmp;
+#endif
 
    numTOTALhandles = 0;
    for (counter = 0; counter < MAXHANDLES; counter++) {
@@ -450,12 +472,12 @@ void ExitCheck (void)
 U16 MemoryAlloc(U16 size, long count, int stored_at)
 {
 /* Returns handle number if successful, 0 or NULL if failure */
-   BYTE far *temp;
    U16 handle = 0;
    int success, use_this_type;
    long toallocate;
 
 #ifndef XFRACT
+   BYTE far *temp;
    long longtmp;
    int mempages = 0;
    struct XMM_Move MoveStruct;
@@ -471,8 +493,8 @@ U16 MemoryAlloc(U16 size, long count, int stored_at)
 
    use_this_type = check_for_mem(stored_at, toallocate);
    if (use_this_type == NOWHERE) {
-      DisplayHandle(handle);
-      return((U16)success);
+      DisplayError(stored_at, toallocate);
+      goodbye();
    }
 
 /* get next available handle */
@@ -579,7 +601,10 @@ dodisk:
       memfile[9] = (char)(handle % 10 + (int)'0');
       memfile[8] = (char)((handle % 100) / 10 + (int)'0');
       memfile[7] = (char)((handle % 1000) / 100 + (int)'0');
-      handletable[handle].Disk.file = dir_fopen(tempdir,memfile, "w+b");
+      if (disktarga)
+         handletable[handle].Disk.file = dir_fopen(workdir,light_name, "a+b");
+      else
+         handletable[handle].Disk.file = dir_fopen(tempdir,memfile, "w+b");
       rewind(handletable[handle].Disk.file);
       if (fseek(handletable[handle].Disk.file,toallocate,SEEK_SET) != 0)
          handletable[handle].Disk.file = NULL;
@@ -594,7 +619,10 @@ dodisk:
       numTOTALhandles++;
       success = TRUE;
       fclose(handletable[handle].Disk.file); /* so clusters aren't lost if we crash while running */
-      handletable[handle].Disk.file = dir_fopen(tempdir,memfile,"r+b"); /* reopen */
+      if (disktarga)
+         handletable[handle].Disk.file = dir_fopen(workdir,light_name, "r+b");
+      else
+         handletable[handle].Disk.file = dir_fopen(tempdir,memfile,"r+b"); /* reopen */
       rewind(handletable[handle].Disk.file);
       handletable[handle].Disk.size = toallocate;
       handletable[handle].Disk.stored_at = DISK;
