@@ -138,7 +138,11 @@ void make_batch_file()
 
    maxcolor = colors;
    strcpy(colorspec,"y");
+#ifndef XFRACT
+   if ((gotrealdac && !reallyega) || (istruecolor && !truemode))
+#else
    if ((gotrealdac && !reallyega) || (istruecolor && !truemode) || fake_lut)
+#endif
    {
       --maxcolor;
 /*    if (maxit < maxcolor)  remove 2 lines */
@@ -221,7 +225,11 @@ prompt_user:
       LOADBATCHPROMPTS("Fourth comment");
       paramvalues[promptnum].type = 0x100 + MAXCMT - 1;
       paramvalues[promptnum++].uval.sbuf = inpcomment[3];
+#ifndef XFRACT
+      if ((gotrealdac && !reallyega) || (istruecolor && !truemode))
+#else
       if ((gotrealdac && !reallyega) || (istruecolor && !truemode) || fake_lut)
+#endif
       {
          LOADBATCHPROMPTS("Record colors?");
          paramvalues[promptnum].type = 0x100 + 13;
@@ -270,7 +278,11 @@ prompt_user:
       far_strcpy(CommandName, inpcommandname);
       for(i=0;i<4;i++)
          far_strncpy(CommandComment[i], inpcomment[i], MAXCMT);
+#ifndef XFRACT
+      if ((gotrealdac && !reallyega) || (istruecolor && !truemode))
+#else
       if ((gotrealdac && !reallyega) || (istruecolor && !truemode) || fake_lut)
+#endif
          if (paramvalues[maxcolorindex].uval.ival > 0 &&
              paramvalues[maxcolorindex].uval.ival <= 256)
             maxcolor = paramvalues[maxcolorindex].uval.ival;
@@ -1084,6 +1096,9 @@ static void write_batch_parms(char *colorinf, int colorsonly, int maxcolor, int
    if(orbit_delay > 0)
       put_parm(s_seqd,s_orbitdelay,orbit_delay);
 
+   if(orbit_interval != 1)
+      put_parm(s_seqd,s_orbitinterval,orbit_interval);
+
    if(start_showorbit > 0)
       put_parm(s_seqs,s_showorbit,s_yes);
 
