@@ -24,6 +24,12 @@
 #include <malloc.h>
 #endif
 
+  /* see Fractint.c for a description of the "include"  hierarchy */
+#include "port.h"
+#include "prototyp.h"
+#include "fractype.h"
+#include "helpdefs.h"
+
 #ifdef __hpux
 #include <sys/param.h>
 #define getwd(a) getcwd(a,MAXPATHLEN)
@@ -34,12 +40,6 @@
 #define getwd(a) getcwd(a,MAXPATHLEN)
 #endif
 
-  /* see Fractint.c for a description of the "include"  hierarchy */
-#include "port.h"
-#include "prototyp.h"
-#include "fractype.h"
-#include "helpdefs.h"
-
 /* Routines used in prompts2.c */
 
    int prompt_checkkey(int curkey);
@@ -124,20 +124,15 @@ int fullscreen_prompt(  /* full-screen prompting routine */
    int rewrite_extrainfo = 0;     /* if 1: rewrite extrainfo to text box   */
    char blanks[78];               /* used to clear text box                */
 
-#ifndef XFRACT
-static FCODE instr1[]  = {"Use " UPARR " and " DNARR " to select values to change"};
+static FCODE instr1[]  = {"Use " UPARR1 " and " DNARR1 " to select values to change"};
 static FCODE instr2a[]  = {"Type in replacement value for selected field"};
-static FCODE instr2b[]  = {"Use " LTARR " or " RTARR " to change value of selected field"};
-#else
-/* Some compilers don't accept "a" "b", so we have to fill in UPARR ourself.  */
-static char far instr1[]  = {"Use up(K) and down(J) to select values to change"};
-static char far instr2a[]  = {"Type in replacement value for selected field"};
-static char far instr2b[]  = {"Use left(H) or right(L) to change value of selected field"};
-#endif
+static FCODE instr2b[]  = {"Use " LTARR1 " or " RTARR1 " to change value of selected field"};
 static FCODE instr3a[] = {"Press ENTER when finished (or ESCAPE to back out)"};
-static FCODE instr3b[] = {"Press ENTER when finished, ESCAPE to back out, or F1 for help"};
-static FCODE instr0a[] = {"No changeable parameters; press ENTER to exit"};
-static FCODE instr0b[] = {"No changeable parameters; press ENTER to exit, ESCAPE to back out, F1 for help"};
+static FCODE instr3b[] = {"Press ENTER when finished, ESCAPE to back out, or "FK_F1" for help"};
+
+static FCODE instr0[] = {"No changeable parameters;"};
+static FCODE instr0a[] = {"Press ENTER to exit"};
+static FCODE instr0b[] = {"Press ENTER to exit, ESC to back out, "FK_F1" for help"};
 
    savelookatmouse = lookatmouse;
    lookatmouse = 0;
@@ -216,7 +211,7 @@ static FCODE instr0b[] = {"No changeable parameters; press ENTER to exit, ESCAPE
          titlewidth = i;
    }
    extralines = extrawidth = i = 0;
-   if ((hdgscan = extrainfo) != 0)
+   if ((hdgscan = extrainfo) != 0) {
       if (*hdgscan == 0)
          extrainfo = NULL;
       else { /* count extra lines, find widest */
@@ -234,6 +229,7 @@ static FCODE instr0b[] = {"No changeable parameters; press ENTER to exit, ESCAPE
                extrawidth = i;
          }
       }
+   }
 
       /* if entry fits in available space, shut off scrolling */
    if(in_scrolling_mode && scroll_row_status == 0
@@ -407,6 +403,8 @@ static FCODE instr0b[] = {"No changeable parameters; press ENTER to exit, ESCAPE
 
 
    if (!anyinput) {
+      putstringcenter(instrrow++,0,80,C_PROMPT_BKGRD,
+        instr0);
       putstringcenter(instrrow,0,80,C_PROMPT_BKGRD,
         (helpmode > 0) ? instr0b : instr0a);
       movecursor(25,80);
@@ -908,7 +906,7 @@ static int select_fracttype(int t) /* subrtn of get_fracttype, separated */
 {
    static FCODE head1[] = {"Select a Fractal Type"};
    static FCODE head2[] = {"Select Orbit Algorithm for Julibrot"};
-   static FCODE o_instr[] = {"Press F2 for a description of the highlighted type"};
+   static FCODE o_instr[] = {"Press "FK_F2" for a description of the highlighted type"};
    char instr[sizeof(o_instr)];
    char head[40];
    int oldhelpmode;
@@ -1272,7 +1270,7 @@ int get_fract_params(int caller)        /* prompt for type-specific parms */
    char *bailnameptr[] = {s_mod,s_real,s_imag,s_or,s_and,s_manh,s_manr};
    struct fractalspecificstuff far *jborbit = NULL;
    struct fractalspecificstuff far *savespecific;
-   int firstparm =0;
+   int firstparm = 0;
    int lastparm  = MAXPARAMS;
    double oldparam[MAXPARAMS];
    int fkeymask = 0x40;
@@ -1362,10 +1360,18 @@ gfp_top:
          firstparm = 0;
       else if(uses_p2)
          firstparm = 2;
+      else if(uses_p3)
+         firstparm = 4;
+      else if(uses_p4)
+         firstparm = 6;
       else
-         firstparm = 4; /* uses_p3 or no parameter */
+         firstparm = 8; /* uses_p5 or no parameter */
 
-      if(uses_p3)  /* set last parameter */
+      if(uses_p5)  /* set last parameter */
+         lastparm = 10;
+      else if(uses_p4)
+         lastparm = 8;
+      else if(uses_p3)
          lastparm = 6;
       else if(uses_p2)
          lastparm = 4;
@@ -1393,8 +1399,12 @@ gfp_top:
    for (i = firstparm; i < lastparm; i++)
    {
       char tmpbuf[30];
-      if (!typehasparm(julibrot?neworbittype:fractype,i,parmprompt[j]))
+      if (!typehasparm(julibrot?neworbittype:fractype,i,parmprompt[j])) {
+         if(curtype == FORMULA || curtype == FFORMULA)
+           if(paramnotused(i))
+              continue;
          break;
+      }
       numparams++;
       choices[promptnum] = parmprompt[j++];
       paramvalues[promptnum].type = 'd';
@@ -1411,6 +1421,12 @@ gfp_top:
       oldparam[i] = paramvalues[promptnum++].uval.dval;
    }
 
+/* The following is a goofy kludge to make reading in the formula
+ * parameters work.
+ */
+   if(curtype == FORMULA || curtype == FFORMULA)
+      numparams = lastparm - firstparm;
+
    numtrig = (curfractalspecific->flags >> 6) & 7;
    if(curtype==FORMULA || curtype==FFORMULA ) {
       numtrig = maxfn;
@@ -1443,7 +1459,7 @@ gfp_top:
       choices[promptnum++] = bailteststr;
    }
 
-   if (i)
+   if (i) {
       if (potparam[0] != 0.0 && potparam[2] != 0.0)
       {
         static FCODE bailpotstr[] = {"Bailout: continuous potential (Y screen) value in use"};
@@ -1466,6 +1482,7 @@ gfp_top:
          sprintf(bailoutmsg,"    (%s default is %d)",tmpptr,i);
          choices[promptnum++] = bailoutmsg;
       }
+   }
    if (julibrot)
    {
       switch(neworbittype)
@@ -1568,9 +1585,8 @@ gfp_top:
       sprintf(msg,"Parameters for fractal type %s",typename);
    if(bf_math == 0)
    {
-      static FCODE pressf6[] = {"\n(Press F6 for corner parameters)"};
+      static FCODE pressf6[] = {"\n(Press "FK_F6" for corner parameters)"};
       far_strcat(msg,pressf6);
-
    }
    else
       fkeymask = 0;
@@ -1599,6 +1615,9 @@ gfp_top:
      promptnum = 0;
      for ( i = firstparm; i < numparams+firstparm; i++)
      {
+        if(curtype == FORMULA || curtype == FFORMULA)
+           if(paramnotused(i))
+              continue;
         if (oldparam[i] != paramvalues[promptnum].uval.dval)
         {
            param[i] = paramvalues[promptnum].uval.dval;
@@ -1637,7 +1656,7 @@ gfp_top:
       bailoutest = Mod;
    setbailoutformula(bailoutest);
 
-   if (i)
+   if (i) {
       if (potparam[0] != 0.0 && potparam[2] != 0.0)
          promptnum++;
       else
@@ -1649,8 +1668,8 @@ gfp_top:
             ret = 1;
          promptnum++;
       }
-
-     if (julibrot)
+   }
+   if (julibrot)
      {
         mxmaxfp    = paramvalues[promptnum++].uval.dval;
         mymaxfp    = paramvalues[promptnum++].uval.dval;
@@ -1864,6 +1883,7 @@ top:
       name_offset = temp_offset = file_offset;
       /* next equiv roughly to fscanf(..,"%40[^* \n\r\t({\032]",buf) */
       len = 0;
+      /* allow spaces in entry names in next JCO 9/2/2003 */
       while (c != ' ' && c != '\t' && c != '(' && c != ';'
            && c != '{' && c != '\n' && c != '\r' && c != EOF && c != '\032')
       {
@@ -1960,7 +1980,12 @@ top:
 static long gfe_choose_entry(int type,char *title,char *filename,char *entryname)
 /* subrtn of get_file_entry, separated so that storage gets freed up */
 {
-   static FCODE o_instr[]={"Press F6 to select different file, F2 for details, F4 to toggle sort "};
+#ifdef XFRACT
+   static FCODE o_instr[]={"Press "FK_F6" to select file, "FK_F2" for details, "FK_F4" to toggle sort "};
+/* keep the above line length < 80 characters */
+#else
+   static FCODE o_instr[]={"Press "FK_F6" to select different file, "FK_F2" for details, "FK_F4" to toggle sort "};
+#endif
    int numentries, i;
    char buf[101];
    struct entryinfo far * far *choices;
@@ -2106,12 +2131,7 @@ static int check_gfe_key(int curkey,int choice)
       putstring(4,0,C_GENERAL_MED,infbuf);
 
       {
-#ifndef XFRACT
-      static FCODE msg[]  = {"\n\n Use " UPARR ", " DNARR ", " RTARR ", " LTARR ", PgUp, PgDown, Home, and End to scroll text\nAny other key to return to selection list"};
-#else
-/* Some compilers don't accept "a" "b", so we have to fill in UPARR ourself.  */
-      static char far msg[] = {"\n\n Press up(K), down(J), right(M), left(N), PgUp, PgDown, Home, and End to scroll text\nAny other key to return to selection list"};
-#endif
+      static FCODE msg[]  = {"\n\n Use "UPARR1", "DNARR1", "RTARR1", "LTARR1", PgUp, PgDown, Home, and End to scroll text\nAny other key to return to selection list"};
       putstring(-1,0,C_GENERAL_LO,msg);
       }
 
