@@ -108,7 +108,7 @@ int get_toggles()
    int old_fillcolor;
    int old_stoppass;
    double old_closeprox;
-   char *calcmodes[] ={"1","2","3","g","g1","g2","g3","g4","g5","g6","b","s","t","d"};
+   char *calcmodes[] ={"1","2","3","g","g1","g2","g3","g4","g5","g6","b","s","t","d","o"};
    char *soundmodes[5]={s_off,s_beep,s_x,s_y,s_z};
    char *insidemodes[]={"numb",s_maxiter,s_zmag,s_bof60,s_bof61,s_epscross,
                          s_startrail,s_period,s_atan,s_fmod};
@@ -120,7 +120,7 @@ int get_toggles()
 
    k = -1;
 
-   LOADCHOICES("Passes (1,2,3, g[uessing], b[oundary], t[esseral], d[iffu.])");
+   LOADCHOICES("Passes (1,2,3, g[uess], b[ound], t[ess], d[iffu], o[rbit])");
    uvalues[k].type = 'l';
    uvalues[k].uval.ch.vlen = 3;
    uvalues[k].uval.ch.llen = sizeof(calcmodes)/sizeof(*calcmodes);
@@ -138,7 +138,8 @@ int get_toggles()
                           : (usr_stdcalcmode == 'b') ? 10 
 			  : (usr_stdcalcmode == 's') ? 11
 			  : (usr_stdcalcmode == 't') ? 12
-			  :        /* "d"iffusion */   13;
+			  : (usr_stdcalcmode == 'd') ? 13
+                          :        /* "o"rbits */      14;
    old_usr_stdcalcmode = usr_stdcalcmode;
    old_stoppass = stoppass;
 #ifndef XFRACT
@@ -275,6 +276,9 @@ int get_toggles()
    if(stoppass < 0 || stoppass > 6 || usr_stdcalcmode != 'g')
       stoppass = 0;
 
+   if(usr_stdcalcmode == 'o' && calctype == lyapunov) /* Oops,lyapunov type */
+      usr_stdcalcmode = old_usr_stdcalcmode; /* doesn't use new & breaks orbits */
+
    if (old_usr_stdcalcmode != usr_stdcalcmode) j++;
    if (old_stoppass != stoppass) j++;
 #ifndef XFRACT
@@ -399,7 +403,7 @@ int get_toggles2()
    int i, j, k;
 
    int old_rotate_lo,old_rotate_hi;
-   int old_distestwidth, old_periodicity;
+   int old_distestwidth, old_periodicity, old_orbit_interval;
    double old_potparam[3],old_inversion[3];
    long old_usr_distest;
 
@@ -463,6 +467,10 @@ int get_toggles2()
    uvalues[k].type = 'i';
    uvalues[k].uval.ival = old_periodicity = usr_periodicitycheck;
 
+   LOADCHOICES("Orbit interval (1 ... 255)");
+   uvalues[k].type = 'i';
+   uvalues[k].uval.ival = old_orbit_interval = (int)orbit_interval;
+
    oldhelpmode = helpmode;
    helpmode = HELPYOPTS;
    i = fullscreen_prompt(hdg,k+1,choices,uvalues,0,NULL);
@@ -532,6 +540,11 @@ int get_toggles2()
    if (usr_periodicitycheck < -255) usr_periodicitycheck = -255;
    if (usr_periodicitycheck != old_periodicity) j = 1;
 
+   orbit_interval = uvalues[++k].uval.ival;
+   if (orbit_interval > 255) orbit_interval = 255;
+   if (orbit_interval < 1) orbit_interval = 1;
+   if (orbit_interval != old_orbit_interval) j = 1;
+
    return(j);
 }
 
@@ -1291,22 +1304,22 @@ int  fr_findnext()              /* Find next file (or subdir) meeting above path
              return -1;
          } else if (dirEntry->d_ino != 0) {
              splitpath(dirEntry->d_name,NULL,NULL,thisname,thisext);
-             if ((searchname[0]=='*' || strcmp(searchname,thisname)==0) &&
-                     (searchext[0]=='*' || strcmp(searchext,thisext)==0)) {
-                 strncpy(DTA.filename,dirEntry->d_name,13);
-                 DTA.filename[12]='\0';
-                 strcpy(tmpname,searchdir);
-                 strcat(tmpname,"/");
-                 strcat(tmpname,dirEntry->d_name);
-                 stat(tmpname,&sbuf);
-                 if ((sbuf.st_mode&S_IFMT)==S_IFREG) {
-                     DTA.attribute = 0;
-                 } else if ((sbuf.st_mode&S_IFMT)==S_IFDIR) {
-                     DTA.attribute = SUBDIR;
-                 } else {
-                     continue;
-                 }
-                 DTA.size = sbuf.st_size;
+             strncpy(DTA.filename,dirEntry->d_name,13);
+             DTA.filename[12]='\0';
+             strcpy(tmpname,searchdir);
+             strcat(tmpname,dirEntry->d_name);
+             stat(tmpname,&sbuf);
+             DTA.size = sbuf.st_size;
+             if ((sbuf.st_mode&S_IFMT)==S_IFREG &&
+                 (searchname[0]=='*' || strcmp(searchname,thisname)==0) &&
+                 (searchext[0]=='*' || strcmp(searchext,thisext)==0)) {
+                 DTA.attribute = 0;
+                 return 0;
+             }
+	     else if (((sbuf.st_mode&S_IFMT)==S_IFDIR) &&
+                 ((searchname[0]=='*' || searchext[0]=='*') ||
+                 (strcmp(searchname,thisname)==0))) {
+                 DTA.attribute = SUBDIR;
                  return 0;
              }
          }
@@ -1699,22 +1712,22 @@ static int filename_speedstr(int row, int col, int vid,
 
 int isadirectory(char *s)
 {
-#ifdef _MSC_VER
    int len;
    char sv;
+#ifdef _MSC_VER
    unsigned attrib = 0;
 #endif
    despace(s);  /* scrunch out white space */
    if(strchr(s,'*') || strchr(s,'?'))
       return(0); /* for my purposes, not a directory */
 
-#ifdef _MSC_VER
    len = strlen(s);
    if(len > 0)
       sv = s[len-1];   /* last char */
    else
       sv = 0;
 
+#ifdef _MSC_VER
    if(_dos_getfileattr(s, &attrib) == 0 && ((attrib&_A_SUBDIR) != 0))
    {
       return(1);  /* not a directory or doesn't exist */
@@ -1735,15 +1748,25 @@ int isadirectory(char *s)
    if(fr_findfirst(s) != 0) /* couldn't find it */
    {
       /* any better ideas?? */
-      if(strchr(s,SLASHC)) /* we'll guess it is a directory */
+     if(sv == SLASHC) /* we'll guess it is a directory */
          return(1);
       else
          return(0);  /* no slashes - we'll guess it's a file */
    }
-   else if(DTA.attribute & SUBDIR)
-      return(1);   /* we're SURE it's a directory */
-   else
-      return(0);
+   else if((DTA.attribute & SUBDIR) != 0) {
+      if(sv == SLASHC) {
+      /* strip trailing slash and try again */
+         s[len-1] = 0;
+         if(fr_findfirst(s) != 0) /* couldn't find it */
+             return(0);
+         else if((DTA.attribute & SUBDIR) != 0)
+             return(1);   /* we're SURE it's a directory */
+         else
+             return(0);
+      } else
+         return(1);   /* we're SURE it's a directory */
+   }
+   return(0);
 #endif
 }
 
