@@ -39,11 +39,15 @@ typedef unsigned int UINT4;
 #define connect connect1
 /* dysize may conflict with time.h */
 #define dysize dysize1
-/* inline is a reserved word */
-#define inline inline1
+/* inline is a reserved word, so fixed lsys.c */
+/* #define inline inline1 */
 
 typedef void (*SignalHandler)(int);
 
+#ifdef NOSIGHAND
+typedef void (*SignalHandler)(int);
+#endif
+
 /* Some stdio.h's don't have this */
 #ifndef SEEK_SET
 #define SEEK_SET 0
